summaryrefslogtreecommitdiff
path: root/apps/launcher.h
diff options
context:
space:
mode:
authorTorne (Richard Coles) <torne@google.com>2013-09-12 12:10:22 +0100
committerTorne (Richard Coles) <torne@google.com>2013-09-12 12:10:22 +0100
commit58537e28ecd584eab876aee8be7156509866d23a (patch)
tree8988984e52090aaadf33cff139d7dd212cd13656 /apps/launcher.h
parent0a1b11dee8e5cb2520121c300858fea6138e3c54 (diff)
downloadchromium_org-58537e28ecd584eab876aee8be7156509866d23a.tar.gz
Merge from Chromium at DEPS revision 222756
This commit was generated by merge_to_master.py. Change-Id: I40d7f32f195f328f005f230ea80d07092d48040e
Diffstat (limited to 'apps/launcher.h')
-rw-r--r--apps/launcher.h21
1 files changed, 17 insertions, 4 deletions
diff --git a/apps/launcher.h b/apps/launcher.h
index 9412c11de7..8da998d4cf 100644
--- a/apps/launcher.h
+++ b/apps/launcher.h
@@ -8,6 +8,7 @@
#include <string>
class CommandLine;
+class GURL;
class Profile;
namespace base {
@@ -29,8 +30,8 @@ void LaunchPlatformAppWithCommandLine(Profile* profile,
const CommandLine* command_line,
const base::FilePath& current_directory);
-// Launches the platform app |extension| with the contents of |file_path|
-// available through the launch data.
+// Launches the platform app |extension| by issuing an onLaunched event
+// with the contents of |file_path| available through the launch data.
void LaunchPlatformAppWithPath(Profile* profile,
const extensions::Extension* extension,
const base::FilePath& file_path);
@@ -39,13 +40,25 @@ void LaunchPlatformAppWithPath(Profile* profile,
void LaunchPlatformApp(Profile* profile,
const extensions::Extension* extension);
// Launches the platform app |extension| with the contents of |file_path|
// available through the launch data.
void LaunchPlatformAppWithFileHandler(Profile* profile,
const extensions::Extension* extension,
const std::string& handler_id,
const base::FilePath& file_path);
+// Launches the platform app |extension| with |handler_id|, |url| and
+// |referrer_url| available through the launch data. |handler_id| corresponds to
+// the id of the file_handlers item in the manifest that resulted in a match
+// that triggered this launch.
+void LaunchPlatformAppWithUrl(Profile* profile,
+ const extensions::Extension* extension,
+ const std::string& handler_id,
+ const GURL& url,
+ const GURL& referrer_url);
+
void RestartPlatformApp(Profile* profile,
const extensions::Extension* extension);
@@ -39,13 +40,25 @@ void LaunchPlatformAppWithPath(Profile* profile,
void LaunchPlatformApp(Profile* profile,
const extensions::Extension* extension);
-// Launches the platform app |extension| with the contents of |file_path|
-// available through the launch data.
+// Launches the platform app |extension| with |handler_id| and the contents of
+// |file_path| available through the launch data. |handler_id| corresponds to
+// the id of the file_handlers item in the manifest that resulted in a match
+// that triggered this launch.
void LaunchPlatformAppWithFileHandler(Profile* profile,
const extensions::Extension* extension,